#

##

    	measures

    	structures

    		{
    			"measures": {
    				"mass + mass equivalents": {
    					"per recipe": {
    						"grams": {
    							"fraction string": "701493850988138503431/11258999068426240000",
    							"scinote string": "6.2305e+1"
    						}
    					}
    				},
    				"energy": {
    					"per recipe": {
    						"food calories": {
    							"fraction string": "918/5",
    							"scinote string": "1.8360e+2"
    						}
    					}
    				}
    			}
    		}